# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-07-19

### Changed

- Initial commit
- ✨ feat: create initial library code (#1)
- ✨ chore: update example usage, enhance mypy configuration, and add test package (#2)
- 🧪 test: adjust auth mock responses in tests (#3)
- Refactor saas-sdk to sqgen-risk (#4)
- Add files and dependencies for mkdocs
